@@ -24,7 +24,10 @@ def make_menu_bar(main):
 
 def _add_menu(menus, menu):
     for submenu in menus:
-        item = hildon.GtkButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
+        #item = hildon.GtkButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
+	item = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | \
+					gtk.HILDON_SIZE_FINGER_HEIGHT, \
+					hildon.BUTTON_ARRANGEMENT_VERTICAL)
         item.set_label(submenu[0])
         if submenu[1] is not None:
             item.connect('clicked', submenu[1])
