@@ -17,26 +17,29 @@ class SurasDialog(object):
         self.dialog.set_title('Noor - ' + _('Choose Sura'))
 	hildon.hildon_gtk_window_set_portrait_flags(self.dialog, hildon.PORTRAIT_MODE_SUPPORT)
         self.dialog.set_border_width(1)
-        self.dialog.set_size_request(400, 200)
+        self.dialog.set_size_request(400, 600)
         self.dialog.connect('destroy', self._quit)
 
-        l = gtk.Label()
-        l.set_markup(_('Choose a sura to display:'))
-        self.combobox = gtk.combo_box_entry_new_text()
+#        l = gtk.Label()
+#        l.set_markup(_('Choose a sura to display:'))
+#        self.combobox = gtk.combo_box_entry_new_text()
+	self.combobox = hildon.TouchSelector(text=True)
         for index, sura in enumerate(quran.suras):
             n = uihelpers._int_to_str(index + 1, config=config)
             self.combobox.append_text('%s - %s' % (n, sura.name))
-        self.combobox.set_active(0)
+        self.combobox.set_active(0,0)
 
-        button = gtk.Button()
+        button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | \
+					gtk.HILDON_SIZE_FINGER_HEIGHT, \
+					hildon.BUTTON_ARRANGEMENT_VERTICAL)
         button.connect('clicked', self._selected)
         button_label = gtk.Label()
         button_label.set_markup(_('Show'))
         button.add(button_label)
 
-        self.dialog.vbox.pack_start(l, True, True, 0)
+#       self.dialog.vbox.pack_start(l, True, True, 0)
         self.dialog.vbox.pack_start(self.combobox, True, True, 0)
-        self.dialog.vbox.pack_start(button, True, True, 0)
+        self.dialog.vbox.pack_start(button, False, True, 0)
         self.selected = False
 
     def _quit(self, *args):
@@ -54,4 +57,4 @@ class SurasDialog(object):
 
     def get_sura(self):
         if self.selected:
-            return self.combobox.get_active() + 1
+            return self.combobox.get_active(0) + 1
